==> jus-core-0.4.0-sources.jar: org/djodjo/comm/jus/error/JusError.java <==
/*
 * Copyright (C) 2014 Kalin Maldzhanski
 * Copyright (C) 2011 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.djodjo.comm.jus.error;

import org.djodjo.comm.jus.NetworkResponse;
import org.djodjo.comm.jus.Request;

/**
 * Exception style class encapsulating Jus errors
 */
@SuppressWarnings("serial")
public class JusError extends Exception {
    public final Request<?> request;
    public final NetworkResponse networkResponse;
    private long networkTimeMs;

    public JusError(Request<?> request) {
        this.request = request;
        networkResponse = null;
    }

    public JusError(Request<?> request, NetworkResponse response) {
        this.request = request;
        networkResponse = response;
    }

    public JusError(String exceptionMessage, Request<?> request) {
       super(exceptionMessage);
        this.request = request;
        networkResponse = null;
    }

    public JusError(String exceptionMessage, Throwable reason, Request<?> request) {
        super(exceptionMessage, reason);
        this.request = request;
        networkResponse = null;
    }

    public JusError(Throwable cause, Request<?> request) {
        super(cause);
        this.request = request;
        networkResponse = null;
    }

    /* package */
    public void setNetworkTimeMs(long networkTimeMs) {
       this.networkTimeMs = networkTimeMs;
    }

    public long getNetworkTimeMs() {
       return networkTimeMs;
    }
}

==> jus-core-0.4.1-sources.jar: org/djodjo/comm/jus/error/JusError.java <==
/*
 * Copyright (C) 2014 Kalin Maldzhanski
 * Copyright (C) 2011 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.djodjo.comm.jus.error;

import org.djodjo.comm.jus.NetworkResponse;

/**
 * Exception style class encapsulating Jus errors
 */
@SuppressWarnings("serial")
public class JusError extends Exception {
    public final NetworkResponse networkResponse;
    private long networkTimeMs;

    public JusError() {
        networkResponse = null;
    }

    public JusError( NetworkResponse response) {
        networkResponse = response;
    }

    public JusError(String exceptionMessage) {
       super(exceptionMessage);
        networkResponse = null;
    }

    public JusError(String exceptionMessage, Throwable reason) {
        super(exceptionMessage, reason);
        networkResponse = null;
    }

    public JusError(Throwable cause) {
        super(cause);
        networkResponse = null;
    }

    /* package */
    public void setNetworkTimeMs(long networkTimeMs) {
       this.networkTimeMs = networkTimeMs;
    }

    public long getNetworkTimeMs() {
       return networkTimeMs;
    }
}
